Welcome to CGDAT’s documentation! — CGDAT 2.0.8 documentation

# Welcome to CGDAT’s documentation!

This package contains a simple csv data analyse GUI which I created for a friend of mine to help him with his data analysis. The repository of this tool can be found on github.

## Contents:

- Installation
  - Install using the python package index (PyPi)
  - Development setup
- Usage
  - Tool interface
  - Functions
  - Console commands
- Additional information
  - Licence
  - Meta
  - Contributing
  - Contributors
  - Credits

## For Developers:

- API Reference

## Indices and tables

- Index
- Module Index
- Search Page